@@ -109,7 +109,7 @@ class QonsoExtractorSFR(QonsoExtractor):
       # Voix Supp
       DebugLog("\n____________________________________\nVoix Supp\n")
       DebugLog("-------------------------------------\n")
-      r = re.compile("vous reste <b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b> de communication dans le cadre de votre option (\d+\s*h)eures", re.DOTALL)
+      r = re.compile("vous reste\s+<b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>\s+de communication dans le cadre de votre option (\d+\s*h)eures", re.DOTALL)
       res = r.search(html)
       if res:
          voixSuppMax = res.group(2)
@@ -118,7 +118,7 @@ class QonsoExtractorSFR(QonsoExtractor):
          self.model.SetConsoVoixSuppMax( voixSuppMax+"00" )
          self.model.SetConsoVoixSupp( res.group(1), invert=True )
       else:
-         r = re.compile("vous reste <b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>\s+sur les\s+<b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>.+?offertes", re.DOTALL)
+         r = re.compile("vous reste\s+<b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>\s+sur les\s+<b>((?:\d{1,2}\s*[Hh])?\s*(?:\d{1,3}\s*(?:mi?n)?))</b>.+?offertes", re.DOTALL)
          res = r.search(html)
          if res:
             voixSuppMax = res.group(2)
